package com.example;

import com.azure.data.appconfiguration.ConfigurationClient;
import com.azure.data.appconfiguration.ConfigurationClientBuilder;
import com.azure.data.appconfiguration.models.ConfigurationSetting;
import com.azure.data.appconfiguration.models.SettingSelector;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class JavaAzureAppConfigApplication {

    private static final Logger LOGGER = LoggerFactory.getLogger(JavaAzureAppConfigApplication.class);
    private final ConfigurationClient configurationClient;
    private final SettingSelector settingSelector;

    public static void main(String[] args) {
        new JavaAzureAppConfigApplication().azureAppConfiguration();
    }

    private void azureAppConfiguration() {
        try {
            LOGGER.info("Read Single Value by key");
            ConfigurationSetting configurationSetting = configurationClient.getConfigurationSetting("config.message", null);
            LOGGER.info("Message: {}", configurationSetting.getValue());

            LOGGER.info("Writing Single Value by key");
            configurationSetting = configurationClient.setConfigurationSetting("config.datasource", null, "Data Source URL");
            LOGGER.info("Data Source URL From Application: {}", configurationSetting.getValue());

            LOGGER.info("Read All Values...");
            configurationClient.listConfigurationSettings(settingSelector).forEach(property -> LOGGER.info("Key: {} \t Value: {}", property.getKey(), property.getValue()));

            LOGGER.info("Remove Single Value by key");
            configurationClient.deleteConfigurationSetting("config.datasource", null);

            LOGGER.info("After Removing Key-Value Read All Values...");
            configurationClient.listConfigurationSettings(settingSelector).forEach(property -> LOGGER.info("Key: {} \t Value: {}", property.getKey(), property.getValue()));
        } catch (Exception e) {
            LOGGER.error(e.getMessage(), e);
        }
    }

    {
        String app_configuration_connection_string = System.getenv("APP_CONFIGURATION_CONNECTION_STRING");
        configurationClient = new ConfigurationClientBuilder().connectionString(app_configuration_connection_string).buildClient();
        settingSelector = new SettingSelector();
    }
}
